﻿using Steema.TeeChart;
using Xamarin.Forms;

namespace ChartTestApp
{
    public abstract class ChartBase : ChartView
    {
        public static Color ChartAxisPenColor = Color.FromRgb(198, 198, 198);
        public static Color ChartLabelTextColor = Color.White;

        public ChartBase()
        {
            VerticalOptions = LayoutOptions.FillAndExpand;
            HorizontalOptions = LayoutOptions.FillAndExpand;

            Chart.Title.Text = "";
            Chart.Title.Visible = false;

            // ### CHART ###
            // Legend
            Chart.Legend.Visible = true;
            Chart.Legend.Alignment = LegendAlignments.Bottom;
            Chart.Legend.LegendStyle = LegendStyles.Series;
            Chart.Legend.Color = Color.White;

            Chart.Legend.TextSymbolGap = 10;
            Chart.Legend.FontSeriesColor = false;

            // Following lines are an attempt to make the Legend Symbol square but do not have desired effect
            //Chart.Legend.Symbol.Squared = true;
            //Chart.Legend.Symbol.Height = 10;
            //Chart.Legend.Symbol.Width = 10;

            // Other
            Chart.Axes.Automatic = true;
            Chart.Panel.Color = Color.Transparent;
            Chart.Zoom.Direction = ZoomDirections.None;
            Chart.Panning.Allow = ScrollModes.None;
        }

        protected void ConfigureChartAxes()
        {
            // ### LEFT AXIS ###
            Chart.Axes.Left.Ticks.Visible = false;
            Chart.Axes.Left.MinorTicks.Visible = false;
            Chart.Axes.Left.Grid.Visible = true;
            Chart.Axes.Left.AxisPen.Visible = true;
            Chart.Axes.Left.AxisPen.Width = 3;
            Chart.Axes.Left.AxisPen.Color = ChartAxisPenColor;
            Chart.Axes.Left.Automatic = true;
            Chart.Axes.Left.Visible = true;
            // Labels
            Chart.Axes.Left.Labels.Visible = true;
            Chart.Axes.Left.Labels.Font.Color = ChartLabelTextColor;
            Chart.Axes.Left.Labels.AutoSize = true;

            // ### RIGHT AXIS ###
            Chart.Axes.Right.Ticks.Visible = false;
            Chart.Axes.Right.MinorTicks.Visible = false;
            Chart.Axes.Right.Grid.Visible = true;
            Chart.Axes.Right.AxisPen.Visible = true;
            Chart.Axes.Right.AxisPen.Width = 3;
            Chart.Axes.Right.AxisPen.Color = ChartAxisPenColor;
            Chart.Axes.Right.Automatic = true;
            Chart.Axes.Right.Visible = true;
            // Labels
            Chart.Axes.Right.Labels.Visible = true;
            Chart.Axes.Right.Labels.Font.Color = ChartLabelTextColor;
            Chart.Axes.Right.Labels.AutoSize = true;

            // ### BOTTOM AXIS ###
            Chart.Axes.Bottom.Automatic = true;
            Chart.Axes.Bottom.Visible = false;

            // ### TOP AXIS ###
            Chart.Axes.Top.Automatic = true;
            Chart.Axes.Top.Visible = false;
        }
    }
}
