﻿using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using Xamarin.Forms;

namespace ChartTestApp
{
    public class VoltageLineChart : ChartBase
    {
        public static Color VmaxColor = Color.Purple;
        public static Color VavgColor = Color.Blue;
        public static Color VminColor = Color.Orange;

        public Line Line_Vmax { get; }
        public Line Line_Vavg { get; }
        public Line Line_Vmin { get; }

        public VoltageLineChart() : base()
        {
            // Create Lines
            Line_Vmax = new Line();
            Line_Vavg = new Line();
            Line_Vmin = new Line();
            Chart.Series.Add(Line_Vmax);
            Chart.Series.Add(Line_Vavg);
            Chart.Series.Add(Line_Vmin);

            // Max Voltage Line Series
            Line_Vmax.LinePen.Width = 4;
            Line_Vmax.LinePen.Color = VmaxColor;
            Line_Vmax.LinePen.Visible = true;
            Line_Vmax.SeriesColor = VmaxColor;
            Line_Vmax.Chart.Zoom.Allow = false;
            Line_Vmax.Chart.Panning.Allow = ScrollModes.None;
            Line_Vmax.LineHeight = 25;
            Line_Vmax.ClickableLine = true;
            Line_Vmax.Title = "Max Voltage";
            Line_Vmax.DefaultNullValue = 0;
            Line_Vmax.VertAxis = VerticalAxis.Both;
            Line_Vmax.HorizAxis = HorizontalAxis.Both;
            Line_Vmax.Visible = true;
            Line_Vmax.RecalcOptions = RecalcOptions.OnModify;

            // Avg Voltage Line Series
            Line_Vavg.LinePen.Width = 4;
            Line_Vavg.LinePen.Color = VavgColor;
            Line_Vavg.LinePen.Visible = true;
            Line_Vavg.SeriesColor = VavgColor;
            Line_Vavg.Chart.Zoom.Allow = false;
            Line_Vavg.Chart.Panning.Allow = ScrollModes.None;
            Line_Vavg.LineHeight = 25;
            Line_Vavg.ClickableLine = true;
            Line_Vavg.Title = "Avg Voltage";
            Line_Vavg.DefaultNullValue = 0;
            Line_Vavg.VertAxis = VerticalAxis.Both;
            Line_Vavg.HorizAxis = HorizontalAxis.Both;
            Line_Vavg.Visible = true;
            Line_Vavg.RecalcOptions = RecalcOptions.OnModify;

            // Min Voltage Line Series
            Line_Vmin.LinePen.Width = 4;
            Line_Vmin.LinePen.Color = VminColor;
            Line_Vmin.LinePen.Visible = true;
            Line_Vmin.SeriesColor = VminColor;
            Line_Vmin.Chart.Zoom.Allow = false;
            Line_Vmin.Chart.Panning.Allow = ScrollModes.None;
            Line_Vmin.LineHeight = 25;
            Line_Vmin.ClickableLine = true;
            Line_Vmin.Title = "Min Voltage";
            Line_Vmin.DefaultNullValue = 0;
            Line_Vmin.VertAxis = VerticalAxis.Both;
            Line_Vmin.HorizAxis = HorizontalAxis.Both;
            Line_Vmin.Visible = true;
            Line_Vmin.RecalcOptions = RecalcOptions.OnModify;

            ConfigureChartAxes();

            Chart.Axes.Left.Labels.ValueFormat = "0.0V";
            Chart.Axes.Right.Labels.ValueFormat = "0.0V";
        }
    }
}

